@@ -28,6 +28,8 @@ if __name__ == "__main__":
 
     import gobject
     print 'Loading...'
+    from hildondesktop import StatusMenuItem
+    from advifswlib.core.maemo5 import *
     hd_plugin_type = get_hd_plugin_type()
     print 'Registering type %s...' % (hd_plugin_type)
     gobject.type_register(hd_plugin_type)
